$TITLE BATCH PROCESSING PROBLEM
$OFFSYMXREF
$OFFSYMLIST
*
*  MINLP FORMULATION OF BATCH DESIGN PROCESSING PROBLEM
*  Design of a multiproduct bacth plant with intermediate storage tank
*  This is a good example on how to limit the disjunction domains
*  (over set J) using the sentence WITH and also how to expand the
*  constraint domain in a disjunction term for a set (I) different of J
*  Reference: Vecchietti A. & Grossmann I. E.
*          LOGMIP: A disjunctive 0-1 non-linear optimizer for process
*          system models, Comp. & Chem Eng. 23, p. 555-565, 1999.

 SETS         I         PRODUCTS               / A , B , C , D , E /
              J         POTENTIAL STAGES                   / 1 * 6 /
              M(J)         POTENTIAL STORAGE TANKS            / 1 * 5 /
              K         BINARIES NEEDED TO REPRESENT N(J)  / 1 * 4 /

 SCALAR       H         HORIZON TIME (available time hrs)  / 6000. /
              ALPHA     COST COEFFICIENT FOR BATCH UNITS   / 250.  /
              COSST     COST COEFF. FOR STORAGE TANK       /150./
              GAMMA     COST COEFF. FOR STORAGE TANK       /0.5 /

 PARAMETERS   Q(I)      PRODUCTION RATE OF PRODUCT i    / A=250000 ,
                         B=150000 , C=180000 , D=160000 , E=120000 /
              PHI
              ACTTL(I,J)
              ACTV(J)   ACTUAL VOLUME
              ACTB(I,J) ACTUAL BATCH SIZES
              ACTN(J)   ACTUAL NUMBER OF UNITS IN PARALLEL  (in phase)
              COEFF(K)
              YMT(J) ;
              COEFF('1') = LOG(1.)  ;
              COEFF('2') = LOG(2.)  ;
              COEFF('3') = LOG(3.)  ;
              COEFF('4') = LOG(4.)  ;


 TABLE        S(I,J)    SIZE FACTOR FOR PRODUCT i IN STAGE j

               1         2         3         4         5         6
    A         7.9       2.        5.2       4.9       6.1       4.2
    B         0.7       0.8       0.9       3.4       2.1       2.5
    C         0.7       2.6       1.6       3.6       3.2       2.9
    D         4.7       2.3       1.6       2.7       1.2       2.5
    E         1.2       3.6       2.4       4.5       1.6       2.1

 TABLE        T(I,J)    PROCESSING TIME OF PRODUCT I IN BATCH J

               1         2         3         4         5         6
    A         6.4       4.7       8.3       3.9       2.1       1.2
    B         6.8       6.4       6.5       4.4       2.3       3.2
    C         1.0       6.3       5.4      11.9       5.7       6.2
    D         3.2       3.0       3.5       3.3       2.8       3.4
    E         2.1       2.5       4.2       3.6       3.7       2.2


 VARIABLES    V(J)      VOLUME OF STAGE J
              BAT(I)    BATCH SIZE of PRODUCT i
              B(I,J)    BATCH SIZE OF PRODUCT i STAGE(j)
              TL(I,J)     CYCLE TIME OF PRODUCT i
              N(J)      NUMBER OF UNIT IN PARALLEL STAGE j
              MI(J)
              COST      TOTAL COST OF BATCH PROCESSING UNITS
              VST(J)    VOLUME OF STORAGE TANK BETEWN STAGE J AND J+1
              E(I) ;
 BINARY   VARIABLES     Y1(K,J), Y2(K,J), Y3(J)                             ;
 POSITIVE VARIABLES     V(J), B(I,J), BAT(I), TL(I,J) , N(J),  MI(J), VST(J);

 EQUATIONS    VOL(I,J)     CALCULATE VOLUME OF STAGE j
              TI(I,J)
              TIME         TIME CONSTRAINT
              VOLUM1(I,J) STORAGE TANK SIZE EQUATION for PRODUCT I STAGE J
              VOLUM2(I,J) STORAGE TANK SIZE EQUATION for PRODUCT I STAGE J
              VOLUMNO(J)
              UNIT1(J)   CALCULATE NUMBER OF PROCESSING UNITS PER STAGE (out of phase)
              UNIT2(J)
              LIM1(J)    LIMIT SELECTION TO ONE NUMBER for N(J)
              LIM2(J)
              BTSZE1(I,J) BATCH SIZE EQUAT. PRODUCT I stage J
              BTSZE2(I,J) BATCH SIZE EQUAT. PRODUCT i stage J
              BTSZNO(I,J)
              FICT      EQUATION VALIS JUST TO SET UP VARIABLE Y3
              OBJ       OBJECTIVE FUNCTION DEFINITION                ;

*******************************************************************************
*  BOUNDS SECTION
 V.LO(J)   =  LOG(300.) ;
 V.UP(J)   =  LOG(3500.);
 VST.LO(J) =  LOG(1.) ;
 VST.UP(J) =  LOG(15000.);
 N.UP(J)   =  LOG(4.)   ;
 MI.UP(J)  =  LOG(4.)   ;
 PARAMETERS   TLLOW(I)       LOWER BOUND ON TL(I)
              TLUPP(I)       UPPER BOUND ON TL(I)                    ;
              TLLOW(I)  =  SMAX(J, T(I,J) / EXP(N.UP(J)))            ;
              TLUPP(I)  =  SMAX(J, T(I,J) )                          ;
 TL.LO(I,J)  =  LOG(TLLOW(I)) ;
 TL.UP(I,J)  =  LOG(TLUPP(I)) ;
 PARAMETERS   BLOW(I)        LOWER BOUND ON B
              BUPP(I)        UPPER BOUND ON B                    ;

              BLOW(I)  =  Q(I) * ( SMAX(J, T(I,J) / EXP(N.UP(J))))/ H;

              BUPP(I)  =  MIN( Q(I) , SMIN(J , EXP(V.UP(J))/S(I,J))) ;

 B.LO(I,J)   =  LOG(BLOW(I)) ;
 B.UP(I,J)   =  LOG(BUPP(I)) ;

 Y3.L(J) = 1.;
 Y1.L('1','1') = 1.      ;
 Y1.L('1','2') = 1.      ;
 Y1.L('1','3') = 1.      ;
 Y1.L('1','4') = 1.      ;
 Y1.L('1','5') = 1.      ;
 Y1.L('1','6') = 1.      ;
 Y2.L('2','1') = 1.      ;
 Y2.L('2','2') = 1.      ;
 Y2.L('2','3') = 1.      ;
 Y2.L('2','4') = 1.      ;
 Y2.L('2','5') = 1.      ;
 Y2.L('2','6') = 1.      ;

 N.L(J)    = SUM( K , COEFF(K)*  Y1.L(K,J) )                       ;
 MI.L(J)   = SUM( K , COEFF(K)*  Y2.L(K,J) )                       ;
 B.L(I,J)  = (B.UP(I,J) + B.LO(I,J))/2.                            ;
 TL.L(I,J) = (TL.UP(I,J) + TL.LO(I,J))/2.                          ;
 V.L(J)    = SMAX(I ,  LOG(S(I,J)) + B.L(I,J))                     ;
 VST.L(J)  = SMAX(I , 2*S(I,J)*B.L(I,J))                           ;
 PHI       = SMAX(I,SMAX(J $(ORD(J) LE 5), B.L(I,J)/B.L(I,J+1)))   ;
************************************************************************************


 VOL(I,J)..     V(J) =G= LOG(S(I,J)) + B(I,J)  - N(J)                   ;
 TI(I,J)..      E(I) =G= LOG(T(I,J))- B(I,J)- MI(J)                     ;
 TIME..         SUM(I , Q(I) * EXP(E(I))) =L= H                                ;
 VOLUM1(I,J)$(ORD(J) LT CARD(J)).. VST(J) =G= LOG(2*5)+B(I,J+1)  ;
 VOLUM2(I,J)$(ORD(J) LT CARD(J)).. VST(J) =G= LOG(2*5)+B(I,J)  ;
 VOLUMNO(J) $(ORD(J) LT CARD(J)).. VST(J) =E= LOG(1.) ;
 BTSZE1(I,J)$(ORD(J) LT CARD(J)).. B(I,J) - B(I,J+1) =L= LOG(10.) ;
 BTSZE2(I,J)$(ORD(J) LT CARD(J)).. B(I,J) - B(I,J+1) =G= -LOG(10.);
 BTSZNO(I,J)$(ORD(J) LT CARD(J)).. B(I,J) - B(I,J+1) =E= 0 ;
 UNIT1(J)..  N(J) =E= SUM(K , COEFF(K) * Y1(K,J))                       ;
 LIM1(J) ..  SUM(K , Y1(K,J)) =E= 1                                     ;
 UNIT2(J)..  MI(J)  =E=       SUM(K , COEFF(K) * Y2(K,J))               ;
 LIM2(J) ..  SUM(K , Y2(K,J)) =E= 1                                     ;
 FICT..         SUM(J,Y3(J)) =G= 0;
 OBJ..       COST =E= ALPHA * SUM(J ,EXP(N(J) + MI(J) + 0.6*V(J))) +
                   150.  * SUM(J$(ORD(J) LT CARD(J)),EXP(0.5 * VST(J)));

 OPTION OPTCR = 0.0                     ;
 OPTIONS LIMCOL   = 0                   ;
 OPTIONS ITERLIM  = 10000000            ;
 OPTION MINLP = LMLBOA                ;

 MODEL   BATCH   / ALL / ;
 SOLVE BATCH USING MINLP  MINIMIZING  COST ;

$ONECHO > "%lm.info%"

disjunction D(j);
D(j) with ord(J) < card(J) is
IF Y3(J) THEN
   volum1(I,J) with (ord(i) >= 1);
   volum2(I,J) with (ord(i) >= 1);
   BTSZE1(I,J) with (ord(i) >= 1);
   BTSZE2(I,J) with (ord(i) >= 1);
ELSE
   volumNO(J)  ;
   BTSZNO(I,J) with ord(i) >= 1;
ENDIF;

init true all;

$offecho
