$TITLE SYNTHESIS: Methanol Production
* DISJUNCTIVE FORMULATION
* This problem corresponds to the synthesis of a methanol production plant
* Reference Turkay & Grossmann
*         LOGIC-BASED MINLP ALGORITHMS FOR THE OPTIMAL SYNTHESIS
*         OF PROCESS NETWORKS, Comp. and Chem. ENg., 20, 8, p. 959-978, 1996
* Note that: -  in this formulation we do not use Logic propositions
*            -  the stop criteria is NLP worsening due to the non-convex model
*               it is implemented via the option file: LMLBOA.opt
$OFFSYMXREF
$OFFSYMLIST

* UNIT OPERATIONS:
*
*                  COMPRESSORS         COMP
*                  EXPANSION VALVE     VALVE
*                  FLASH               FLSH
*                  HEAT EXCHANGERS     HEC & HEH
*                  REACTOR             RCT

 SETS    I              SET OF UNITS                  / 1 * 19 /
         STR            SET OF PROCESS STREAMS        / 1 * 33 /
         COM            SET OF CHEMICAL COMPONENTS    /
                                  H2       HYDROGEN
                                  CO       CARBON-MONOXIDE
                                  CH3OH    METHANOL
                                  CH4      METHANE             /
         COMP           SET OF COMPRESSORS            / 1 * 6  /
         HEC            SET OF COOLERS                / 1 * 4  /
         HEH            SET OF HEATERS                / 1 * 3  /
         RCT            SET OF REACTORS               / 1 * 2  / ;

 SCALARS
         ALPHA          COMPRESSOR COEFFICIENT        / 0.720  /
         CEFF           COMPRESSOR EFFICIENCY         / 0.750  /
         GAM            RATIO OF CP TO CV             / 0.23077/
         ep             A.V. value to avoid division by zero /0.0001/
*   COSTS IN UNITS OF  $1000. PER YEAR
         COSTELEC       ELECTRICITY COST ($255. PER KW-YR) / 0.255 /
         COSTQC         COOLING COST   ($700  PER 1E9 KJ)  /   700 /
         COSTQH         HEATING COST   ($8000 PER 1E9 KJ)  /  8000 /
         HEATRXN        HEAT OF REACTION                   / -15.0 /
         CP             HEAT CAPACITY (KJ PER KGMOLE-K)    /  35.0 /;

 PARAMETER    ANTA(COM)   ANTOINE COEFFICIENT                        /
       H2 = 13.6333 , CO = 14.3686 , CH3OH = 18.5875 , CH4 = 15.2243 /

              ANTB(COM)   ANTOINE COEFFICIENT                        /
       H2 = 164.9   , CO = 530.22  , CH3OH = 3626.55 , CH4 = 897.84  /

             ANTC(COM)   ANTOINE COEFFICIENT                         /
       H2 = 3.19    , CO = -13.15  , CH3OH = -34.29  , CH4 = -7.16   /

              VPAR(RCT)      VOLUME - CONVERSION PARAMETERS  /
                     1 = 0.050 , 2 = 0.100                   /;

*             REACTION:      2 H2 + CO  --->  CH3OH ( CH4 IS INERT )

Binary VARIABLES Y(I);
* ----------
* - STREAM -
* ----------
POSITIVE VARIABLES
        F(STR)         STREAM FLOWRATES    (KG-MOLE PER SEC)
        FC(STR,COM)    COMPONENT FLOWRATES (KG-MOLE PER SEC)
        P(STR)         STREAM PRESSURE     (MEGA_PASCAL)
        T(STR)         STREAM TEMPERATURE  (100 K)
        CEQ(I)       ;

* -------------------
* - FLASH SEPARATOR -
* -------------------
POSITIVE VARIABLES
        FLSHT          FLASH TEMPERATURE   (100 K)
        FLSHP          FLASH PRESSURE      (MEGA-PASCAL)
        VP(COM)        VAPOR PRESSURE      (MEGA-PASCAL)
        EFLSH(COM)     VAPOR PHASE RECOVERY IN FLASH    ;

* ----------------
* - SPLIT POINTS -
* ----------------
POSITIVE VARIABLES
        E26            SPLIT FRACTION FOR RECYCLE            ;

* --------------------------------
* - SINGLE STAGE FEED COMPRESSOR -
* --------------------------------
POSITIVE VARIABLES
        ELEC(COMP)     ELECTRICITY REQUIREMENT (KW)
        PRAT(COMP)     RATIO OF OUTLET TO INLET PRESSURE    ;

* ------------------------------------------------
* - INTERCOOLER OF THE TWO STAGE FEED COMPRESSOR -
* ------------------------------------------------
POSITIVE VARIABLES
        QC(HEC)        COOLING UTILITY REQUIREMENT (1E+12 KJ PER YR) ;

* --------------
* - REACTOR #1 -
* --------------
POSITIVE VARIABLES
        RCTT(RCT)      REACTOR TEMPERATURE    (100 K)
        RCTP(RCT)      REACTOR PRESSURE       (M-PA)
        RCTVOL(RCT)    REACTOR VOLUME         (CUBIC METER)
        CONV(RCT)      CONVERSION OF KEY COMPONENT
        CONVEQ(RCT)    EQUILIBRIUM CONVERSION OF KEY
        CONSUM(RCT)    CONSUMPTION RATE OF KEY  ;

* -----------------------
* - REACTOR FEED HEATER -
* -----------------------
POSITIVE VARIABLES
        QH(HEH)        HEATING UTILITY REQUIREMENT (1E+12 KJ PER YR) ;

* ----------------------
* - OBJECTIVE FUNCTION -
* ----------------------
VARIABLES
        PROF         OVERALL PROFIT      ($1000 PER YEAR)             ;



CEQ.L(I)= 0.;


 EQUATIONS
    FBAL(STR),  PURITY                                 ;
FBAL(STR)      ..  F(STR) =E= SUM(COM, FC(STR, COM))   ;
PURITY         ..  FC('23','CH3OH') =G= 0.90 * F('23') ;

* -----------
* - FEED #1 -
* -----------
 EQUATIONS
    FEE1CA, FEE1CB, FEE1CD, FEE1TEMP, FEE1PRES, FEE1N(COM), FEE1BM1(COM),
    FEE1TNO, FEE1PNO;
FEE1CA     ..  FC('1','H2')    =E= 0.60 * F('1')  ;
FEE1CB     ..  FC('1','CO')    =E= 0.25 * F('1')  ;
FEE1CD     ..  FC('1','CH4')   =E= 0.15 * F('1')  ;
FEE1BM1(COM).. FC('1',COM) =L= 5.0               ;
FEE1TEMP   ..  T('1')          =E= 3.0            ;
FEE1PRES   ..  P('1')          =E= 1.0            ;
FEE1N(COM) ..  FC('1',COM)     =E= 0.0            ;
FEE1TNO..      T('1')          =E= 0.0            ;
FEE1PNO..      P('1')          =E= 0.0            ;

* -----------------
* - MIXING POINTS -
* -----------------
 EQUATIONS
    MIX1C1(COM), MIX1TEMP1, MIX1PRES1
    MIX2C1(COM), MIX2TEMP1, MIX2PRES1
    MIX3C(COM),  MIX3TEMP , MIX3PRES1, MIX3PRES2
    MIX4C1(COM), MIX4TEMP1, MIX4PRES1
    MIX5C1(COM), MIX5TEMP1, MIX5PRES1           ;

MIX1C1(COM)  ..  FC('3',COM)  =E= FC('1',COM) +  FC('2',COM)     ;
MIX1TEMP1    ..  T('3')       =E= T('1')  + T('2')       ;
MIX1PRES1    ..  P('3')       =E= P('1')  + P('2')       ;


MIX2C1(COM) ..  FC('10',COM) =E= FC('6',COM) +  FC('9',COM)      ;
MIX2TEMP1   ..  T('10')      =E= T('6')  +  T('9')               ;
MIX2PRES1   ..  P('10')      =E= P('6')  +  P('9')        ;

MIX3C(COM)  ..  FC('11',COM) =E= FC('10',COM) + FC('33',COM)   ;
MIX3TEMP    ..  F('11')* T('11') =E= (F('10')*T('10')+F('33')*T('33'))  ;
MIX3PRES1   ..  P('11')      =E=  P('33')          ;
MIX3PRES2   ..  P('11') =E= P('10');

MIX4C1(COM) ..  FC('18',COM) =E= FC('16',COM) + FC('17',COM)  ;
MIX4TEMP1   ..  T('18')      =E= T('16') +    T('17')         ;
MIX4PRES1   ..  P('18')      =E= P('16') + P('17')       ;

MIX5C1(COM) ..  FC('33',COM) =E= FC('29',COM) + FC('32',COM)     ;
MIX5TEMP1   ..  T('33')      =E= T('29')  +  T('32')       ;
MIX5PRES1   ..  P('33')      =E= P('29')  +  P('32')       ;



* ----------------
* - SPLIT POINTS -
* ----------------
 EQUATIONS
    SPL1C1(COM), SPL1TEMP1, SPL1PRES1
    SPL2C1(COM), SPL2TEMP1, SPL2PRES1
    SPL3C1(COM), SPL3C2(COM), SPL3TEMP1, SPL3PRES1,
    SPL3TEMP2, SPL3PRES2
    SPL4C1(COM), SPL4TEMP1, SPL4PRES1;

SPL1C1(COM) ..  FC('4',COM)+ FC('5',COM)   =E= FC('3',COM)   ;
SPL1TEMP1..     T('4') + T('5')      =E= T('3')        ;
SPL1PRES1..     P('4') + P('5')     =E= P('3')        ;


SPL2C1(COM)..   FC('14',COM)+ FC('15',COM)  =E= FC('13',COM)  ;
SPL2TEMP1  ..   T('14')  + T('15')    =E= T('13')       ;
SPL2PRES1  ..   P('14')  + P('15')    =E= P('13')       ;


SPL3C1(COM) ..  FC('24',COM) =E= FC('21',COM) * (1 - E26)    ;
SPL3C2(COM) ..  FC('26',COM) =E= FC('21',COM) - FC('24',COM) ;
SPL3TEMP1   ..  T('24')      =E= T('21')          ;
SPL3TEMP2   ..  T('26')      =E= T('21')          ;
SPL3PRES1   ..  P('24')      =E= P('21')          ;
SPL3PRES2   ..  P('26')      =E= P('21')          ;


SPL4C1(COM) ..  FC('27',COM) + FC('28',COM)   =E= FC('26',COM)  ;
SPL4TEMP1   ..  T('27') + T('28')  =E= T('26')       ;
SPL4PRES1   ..  P('27') + P('28') =E= P('26')        ;


* --------------------------------
* - SINGLE STAGE FEED COMPRESSOR -
* --------------------------------
POSITIVE VARIABLES
        ELEC(COMP)     ELECTRICITY REQUIREMENT (KW)
        PRAT(COMP)     RATIO OF OUTLET TO INLET PRESSURE          ;
PARAMETERS
             ELUP(COMP) / 1  3.7407
                          2  2.6116
                          3  2.6116
                          4  4.3386
                          5  2.1692
                          6  2.1692 /
             ELLO(COMP) / 1  3.3556
                          2  1.7723
                          3  1.7723
                          4  1.0434
                          5  0.9467
                          6  0.9467 /
             PRUP(COMP) / 1  1.7400
                          2  1.4341
                          3  1.3027
                          4  1.2666
                          5  1.1333
                          6  1.1176 /
             PRLO(COMP) / 1  1.7400
                          2  1.4165
                          3  1.2873
                          4  1.0779
                          5  1.0429
                          6  1.0411 /                             ;
 EQUATIONS
    COM1CMB(COM), COM1TEMP, COM1ELEC, COM1RATIO
    COM1BM1, COM1BM2(COM), COM1BM3, COM1BM4, COM1BM5
    COM1BM6, COM1BM7, COM1BM8, COM1BM9, COM1NO1(COM), COM1NO2(COM)
    COM1TNO1, COM1TNO2, COM1PNO1, COM1PNO2, PRATNO1, ELECNO1    ;

COM1CMB(COM) .. FC('6',COM) =E= FC('4',COM)             ;
COM1TEMP     .. T('6')      =E= PRAT('1') * T('4')      ;
COM1ELEC     .. ELEC('1')   =E= ALPHA * (PRAT('1') - 1) *
                                  T('4') * F('4') / (10 * CEFF * GAM) ;
COM1RATIO    .. PRAT('1')   =E= (P('6') / (P('4')+ ep)) ** GAM;
COM1BM1      ..  ELEC('1')  =L= ELUP('1')                  ;
COM1BM2(COM) ..  FC('4',COM)=L=  5.0                       ;
COM1BM3      ..  PRAT('1')  =L= PRUP('1')                  ;
COM1BM4      ..  P('4')     =L=  1.0                       ;
COM1BM5      ..  P('6')     =L= 11.5                       ;
COM1BM6      ..  T('4')     =L=  3.0                       ;
COM1BM7      ..  T('6')     =L=  6.0                       ;
COM1BM8      ..  ELEC('1')  =G= ELLO('1')                  ;
COM1BM9      ..  PRAT('1')  =G= PRLO('1')                  ;
COM1NO1(COM) ..  FC('4',COM)=E= 0.                         ;
COM1NO2(COM) ..  FC('6',COM)=E= 0.                         ;
COM1TNO1 ..  T('4')    =E= 0.                         ;
COM1TNO2 ..  T('6')    =E= 0.                         ;
COM1PNO1 ..  P('4')    =E= 0.                         ;
COM1PNO2 ..  P('6')    =E= 0.                         ;
PRATNO1..  PRAT('1')   =E= 0.                         ;
ELECNO1..  ELEC('1')   =E= 0.                         ;


* ------------------------------------------------
* - FIRST STAGE OF THE TWO STAGE FEED COMPRESSOR -
* ------------------------------------------------
 EQUATIONS
    COM2CMB(COM), COM2TEMP, COM2ELEC, COM2RATIO, COSCOM4
    COM2BM1, COM2BM2(COM), COM2BM3, COM2BM4, COM2BM5
    COM2BM6, COM2BM7, COM2BM8, COM2BM9, COM2PRE, COM2NO1(COM), COM2NO2(COM)
    COM2TNO1, COM2TNO2, COM2PNO1, COM2PNO2, PRATNO2, ELECNO2  ;

COM2CMB(COM) .. FC('7',COM) =E= FC('5',COM)             ;
COM2TEMP     .. T('7')      =E= PRAT('2') * T('5')      ;
COM2ELEC     .. ELEC('2')   =E= ALPHA * (PRAT('2') - 1) *
                                  T('5') * F('5') / (10 * CEFF * GAM) ;
COM2RATIO    .. PRAT('2')   =E= (P('7') / (P('5')+ ep)) ** GAM;
COSCOM4      .. CEQ('4') =E= 25 ;
COM2PRE      ..  P('7')     =G= P('5')                    ;
COM2BM1      ..  ELEC('2')  =L= ELUP('2')                 ;
COM2BM2(COM) ..  FC('5',COM)=L=  5.0                      ;
COM2BM3      ..  PRAT('2')  =L= PRUP('2')                 ;
COM2BM4      ..  P('5')     =L=  1.0                      ;
COM2BM5      ..  P('7')     =L= 11.5                      ;
COM2BM6      ..  T('5')     =L=  3.0                      ;
COM2BM7      ..  T('7')     =L=  5.0                      ;
COM2BM8      ..  ELEC('2')  =G= ELLO('2')                 ;
COM2BM9      ..  PRAT('2')  =G= PRLO('2')                 ;
COM2NO1(COM) ..  FC('5',COM)=E= 0.                        ;
COM2NO2(COM) ..  FC('7',COM)=E= 0.                        ;
COM2TNO1 ..  T('5')    =E= 0.                         ;
COM2TNO2 ..  T('7')    =E= 0.                         ;
COM2PNO1 ..  P('5')    =E= 0.                         ;
COM2PNO2 ..  P('7')    =E= 0.                         ;
PRATNO2..  PRAT('2')   =E= 0.                         ;
ELECNO2..  ELEC('2')   =E= 0.                         ;

* -------------------------------------------------
* - SECOND STAGE OF THE TWO STAGE FEED COMPRESSOR -
* -------------------------------------------------
 EQUATIONS
    COM3CMB(COM), COM3TEMP, COM3ELEC, COM3RATIO, COM3R , COSCOM6
    COM3BM1, COM3BM2(COM), COM3BM3, COM3BM4, COM3BM5
    COM3BM6, COM3BM7, COM3BM8, COM3BM9, COM3NO1(COM), COM3NO2(COM)
    COM3TNO1, COM3TNO2, COM3PNO1, COM3PNO2, PRATNO3, ELECNO3 ;

COM3CMB(COM) .. FC('9',COM) =E= FC('8',COM)             ;
COM3TEMP     .. T('9')      =E= PRAT('3') * T('8')      ;
COM3ELEC     .. ELEC('3')   =E= ALPHA * (PRAT('3') - 1) *
                                  T('8') * F('8') / (10 * CEFF * GAM) ;
COM3RATIO    .. PRAT('3')   =E= (P('9') / (P('8')+ ep)) ** GAM;
COM3R        .. ELEC('3')   =E= ELEC('2')                  ;
COSCOM6      .. CEQ('6') =E= 25 ;
COM3BM1      ..  ELEC('3')  =L= ELUP('3')                  ;
COM3BM2(COM) ..  FC('8',COM)=L=  5.0                       ;
COM3BM3      ..  PRAT('3')  =L= PRUP('3')                  ;
COM3BM4      ..  P('8')     =L= 11.5                       ;
COM3BM5      ..  P('9')     =L= 15.0                       ;
COM3BM6      ..  T('8')     =L=  5.0                       ;
COM3BM7      ..  T('9')     =L=  6.0                       ;
COM3BM8      ..  ELEC('3')  =G= ELLO('3')                  ;
COM3BM9      ..  PRAT('3')  =G= PRLO('3')                  ;
COM3NO1(COM) ..  FC('8',COM)=E= 0.                        ;
COM3NO2(COM) ..  FC('9',COM)=E= 0.                        ;
COM3TNO1 ..  T('8')    =E= 0.                         ;
COM3TNO2 ..  T('9')    =E= 0.                         ;
COM3PNO1 ..  P('8')    =E= 0.                         ;
COM3PNO2 ..  P('9')    =E= 0.                         ;
PRATNO3..  PRAT('3')   =E= 0.                         ;
ELECNO3..  ELEC('3')   =E= 0.                         ;

* -----------------------------------
* - SINGLE STAGE RECYCLE COMPRESSOR -
* -----------------------------------
 EQUATIONS
    COM4CMB(COM), COM4TEMP, COM4ELEC, COM4RATIO, COM4T
    COM4BM1, COM4BM2(COM), COM4BM3, COM4BM4, COM4BM5
    COM4BM6, COM4BM7, COM4BM8, COM4BM9, COM4NO1(COM), COM4NO2(COM)
    COM4TNO1, COM4TNO2, COM4PNO1, COM4PNO2, PRATNO4, ELECNO4     ;

COM4CMB(COM) .. FC('29',COM) =E= FC('27',COM)            ;
COM4TEMP     .. T('29')      =E= PRAT('4') * T('27')     ;
COM4ELEC     .. ELEC('4')    =E= ALPHA * (PRAT('4') - 1) *
                                   T('27') * F('27') / (10 * CEFF * GAM);
COM4RATIO    .. PRAT('4')    =E= (P('29')/(P('27')+ ep)) ** GAM;
COM4T        .. T('29') =G= T('27') ;
COM4BM1      ..  ELEC('4')   =L= ELUP('4')               ;
COM4BM2(COM) ..  FC('27',COM)=L=  6.0                    ;
COM4BM3      ..  PRAT('4')   =L= PRUP('1')               ;
COM4BM4      ..  P('27')     =L= 13.5                    ;
COM4BM5      ..  P('29')     =L= 15.0                    ;
COM4BM6      ..  T('27')     =L=  4.0                    ;
COM4BM7      ..  T('29')     =L=  5.0                    ;
COM4BM8      ..  ELEC('4')   =G= ELLO('4')               ;
COM4BM9      ..  PRAT('4')   =G= PRLO('4')               ;
COM4NO1(COM) ..  FC('27',COM)=E= 0.                        ;
COM4NO2(COM) ..  FC('29',COM)=E= 0.                        ;
COM4TNO1 ..  T('27')    =E= 0.                         ;
COM4TNO2 ..  T('29')    =E= 0.                         ;
COM4PNO1 ..  P('27')    =E= 0.                         ;
COM4PNO2 ..  P('29')    =E= 0.                         ;
PRATNO4..    PRAT('4')   =E= 0.                         ;
ELECNO4..    ELEC('4')   =E= 0.                         ;

* ---------------------------------------------------
* - FIRST STAGE OF THE TWO STAGE RECYCLE COMPRESSOR -
* ---------------------------------------------------
 EQUATIONS
    COM5CMB(COM), COM5TEMP, COM5ELEC, COM5RATIO, COSCOM17, COM5PRE
    COM5BM1, COM5BM2(COM), COM5BM3, COM5BM4, COM5BM5
    COM5BM6, COM5BM7, COM5BM8, COM5BM9, COM5NO1(COM), COM5NO2(COM)
    COM5TNO1, COM5TNO2, COM5PNO1, COM5PNO2, PRATNO5, ELECNO5       ;

COM5CMB(COM) .. FC('30',COM) =E= FC('28',COM)            ;
COM5TEMP     .. T('30')      =E= PRAT('5') * T('28')     ;
COM5ELEC     .. ELEC('5')    =E= ALPHA * (PRAT('5') - 1) *
                                   T('28') * F('28') / (10 * CEFF * GAM);
COM5RATIO    .. PRAT('5')    =E= (P('30')/(P('28')+ep)) ** GAM;
COSCOM17     .. CEQ('17') =E= 25 ;
COM5PRE      ..  P('30')     =G= P('28')                 ;
COM5BM1      ..  ELEC('5')   =L= ELUP('5')               ;
COM5BM2(COM) ..  FC('28',COM)=L=  6.0                    ;
COM5BM3      ..  PRAT('5')   =L= PRUP('5')               ;
COM5BM4      ..  P('28')     =L= 13.5                    ;
COM5BM5      ..  P('30')     =L= 15.0                    ;
COM5BM6      ..  T('28')     =L=  4.0                    ;
COM5BM7      ..  T('30')     =L=  4.5                    ;
COM5BM8      ..  ELEC('5')   =G= ELLO('5')               ;
COM5BM9      ..  PRAT('5')   =G= PRLO('5')               ;
COM5NO1(COM) ..  FC('30',COM)=E= 0.                      ;
COM5NO2(COM) ..  FC('28',COM)=E= 0.                      ;
COM5TNO1 ..  T('28')    =E= 0.                         ;
COM5TNO2 ..  T('30')    =E= 0.                         ;
COM5PNO1 ..  P('28')    =E= 0.                         ;
COM5PNO2 ..  P('30')    =E= 0.                         ;
PRATNO5..    PRAT('5')   =E= 0.                         ;
ELECNO5..    ELEC('5')   =E= 0.                         ;

* ----------------------------------------------------
* - SECOND STAGE OF THE TWO STAGE RECYCLE COMPRESSOR -
* ----------------------------------------------------
 EQUATIONS
    COM6CMB(COM), COM6TEMP, COM6ELEC, COM6RATIO, COM6R ,COSCOM19
    COM6BM1, COM6BM2(COM), COM6BM3, COM6BM4, COM6BM5
    COM6BM6, COM6BM7, COM6BM8, COM6BM9, COM6NO1(COM), COM6NO2(COM)
    COM6TNO1, COM6TNO2, COM6PNO1, COM6PNO2, PRATNO6, ELECNO6  ;

COM6CMB(COM) .. FC('32',COM) =E= FC('31',COM)            ;
COM6TEMP     .. T('32')      =E= PRAT('6') * T('31')     ;
COM6ELEC     ..  ELEC('6')    =E= ALPHA * (PRAT('6') - 1) *
                                   T('31') * F('31') / (10 * CEFF * GAM);
COM6RATIO    ..  PRAT('6')    =E= (P('32')/(P('31')+ ep)) ** GAM;
COM6R        ..  ELEC('6')    =E= ELEC('5')               ;
COSCOM19     ..  CEQ('19')    =E= 25 ;
COM6BM1      ..  ELEC('6')   =L= ELUP('6')                ;
COM6BM2(COM) ..  FC('31',COM)=L=  6.0                     ;
COM6BM3      ..  PRAT('6')   =L= PRUP('6')                ;
COM6BM4      ..  P('31')     =L= 13.5                     ;
COM6BM5      ..  P('32')     =L= 15.0                     ;
COM6BM6      ..  T('31')     =L=  4.5                     ;
COM6BM7      ..  T('32')     =L=  5.0                     ;
COM6BM8      ..  ELEC('6')   =G= ELLO('6')                ;
COM6BM9      ..  PRAT('6')   =G= PRLO('6')                ;
COM6NO1(COM) ..  FC('31',COM)=E= 0.                       ;
COM6NO2(COM) ..  FC('32',COM)=E= 0.                       ;
COM6TNO1 ..  T('31')    =E= 0.                         ;
COM6TNO2 ..  T('32')    =E= 0.                         ;
COM6PNO1 ..  P('31')    =E= 0.                         ;
COM6PNO2 ..  P('32')    =E= 0.                         ;
PRATNO6..    PRAT('6')   =E= 0.                         ;
ELECNO6..    ELEC('6')   =E= 0.                         ;

* ------------------------------------------------
* - INTERCOOLER OF THE TWO STAGE FEED COMPRESSOR -
* ------------------------------------------------
 EQUATIONS  COO1CMB(COM), COO1DUTY, COO1PRES, COO1BM1, COO1BM2(COM)
            COO1BM3, COO1BM4, COO1BM5, COO1NO1(COM), COO1NO2(COM)
            COO1TNO1, COO1TNO2, COO1PNO1, COO1PNO2, QNO1     ;

COO1CMB(COM) .. FC('8',COM) =E= FC('7',COM)      ;
COO1DUTY     .. QC('1')     =E= (F('7')*T('7') -
                F('8')*T('8')) * CP * (3600*8500*100*1.0E-12)   ;
COO1PRES     .. P('8')      =E= P('7')           ;
COO1BM1      .. QC('1')     =L= 10.0             ;
COO1BM2(COM) .. FC('7',COM) =L=  5.0             ;
COO1BM3      .. P('8')      =L= 11.5             ;
COO1BM4      .. T('8')      =L=  5.0             ;
COO1BM5      .. T('8')      =G=  3.0             ;
COO1NO1(COM) ..  FC('7',COM)=E= 0.               ;
COO1NO2(COM) ..  FC('8',COM)=E= 0.               ;
COO1TNO1 ..  T('7')    =E= 0.                         ;
COO1TNO2 ..  T('8')    =E= 0.                         ;
COO1PNO1 ..  P('7')    =E= 0.                         ;
COO1PNO2 ..  P('8')    =E= 0.                         ;
QNO1..       QC('1')   =E= 0.                         ;

* -----------------------
* - REACTOR FEED COOLER -
* -----------------------
 EQUATIONS    COO2CMB(COM), COO2DUTY, COO2PRES, COO2BM1          ;

COO2CMB(COM) ..  FC('12',COM) =E= FC('11',COM)                   ;
COO2DUTY     ..  QC('2')      =E= (F('11')*T('11') -
                 F('12')*T('12')) * CP * (3600*8500*100*1.0E-12) ;
COO2PRES     ..  P('12')      =E= P('11')                        ;
COO2BM1      ..  QC('2')      =L= 10.0                           ;

* --------------------------
* - FLASH SEPARATOR COOLER -
* --------------------------
 EQUATIONS COO3CMB(COM), COO3DUTY, COO3PRES;
* COO3BM1, COO3BM2   ;

COO3CMB(COM) ..  FC('20',COM) =E= FC('19',COM)                  ;
COO3DUTY..       QC('3')      =E= (F('19')*T('19') -
                 F('20')*T('20')) * CP * (3600*8500*100*1.0E-12);
COO3PRES     ..  P('20')      =E= P('19')                       ;
*COO3BM1      ..  QC('3')      =L= 1.5185                        ;
*COO3BM2      ..  QC('3')      =L= 1.1375                        ;

* ---------------------------------------------------
* - INTERCOOLER OF THE TWO STAGE RECYCLE COMPRESSOR -
* ---------------------------------------------------
 EQUATIONS    COO4CMB(COM), COO4DUTY, COO4PRES,
              COO4BM1, COO4BM2(COM), COO4BM3, COO4NO1(COM), COO4NO2(COM)
              COO4TNO1, COO4TNO2, COO4PNO1, COO4PNO2, QNO2  ;

COO4CMB(COM) ..  FC('31',COM) =E= FC('30',COM)                   ;
COO4DUTY     ..  QC('4')      =E= (F('30')*T('30') -
                 F('31')*T('31')) * CP * (3600*8500*100*1.0E-12) ;
COO4PRES     ..  P('31')      =E= P('30')                        ;
COO4BM1      ..  QC('4')      =L= 10.0                           ;
COO4BM2(COM) ..  FC('30',COM) =L=  5.0                           ;
COO4BM3      ..  P('31')      =L= 13.0                           ;
COO4NO1(COM) ..  FC('31',COM)=E= 0.               ;
COO4NO2(COM) ..  FC('30',COM)=E= 0.               ;
COO4TNO1 ..  T('30')    =E= 0.                    ;
COO4TNO2 ..  T('31')    =E= 0.                    ;
COO4PNO1 ..  P('30')    =E= 0.                    ;
COO4PNO2 ..  P('31')    =E= 0.                    ;
QNO2..       QC('2')    =E= 0.                    ;

* -----------------------
* - REACTOR FEED HEATER -
* -----------------------
 EQUATIONS       HEA1CMB(COM), HEA1DUTY, HEA1PRES,  HEA1BM1      ;

HEA1CMB(COM).. FC('13',COM) =E= FC('12',COM)                     ;
HEA1DUTY    .. QH('1')      =E= (F('13')*T('13') -
               F('12')*T('12')) * CP * (3600*8500*100*1.0E-12)   ;
HEA1PRES    .. P('13')      =E= P('12')                          ;
HEA1BM1     .. QH('1')      =L= 10.0                             ;

* ------------------
* - PRODUCT HEATER -
* ------------------
 EQUATIONS HEA2CMB(COM), HEA2DUTY, HEA2PRES,  HEA2BM1            ;

HEA2CMB(COM)  .. FC('23',COM) =E= FC('22',COM)                   ;
HEA2DUTY      .. QH('2')      =E= (F('23')*T('23') -
                 F('22')*T('22')) * CP * (3600*8500*100*1.0E-12) ;
HEA2PRES      .. P('23')      =E= P('22')                        ;
HEA2BM1      ..  QH('2')      =L= 10.0                           ;


* ---------------------
* - BY-PRODUCT HEATER -
* ---------------------
 EQUATIONS HEA3CMB(COM), HEA3DUTY, HEA3PRES,   HEA3BM1           ;

HEA3CMB(COM) .. FC('25',COM) =E= FC('24',COM)                    ;
HEA3DUTY     .. QH('3')      =E= (F('25')*T('25') -
                F('24')*T('24')) * CP * (3600*8500*100*1.0E-12)  ;
HEA3PRES     .. P('25')      =E= P('24')                         ;
HEA3BM1      .. QH('3')      =L= 10.0                            ;

* --------------
* - REACTOR #1 -
* --------------

 EQUATIONS RCT1MB, RCT1HB, RCT1CMA, RCT1CMB, RCT1CMC, RCT1CMD
           RCT1EQ, RCT1CO, RCT1VO,  RCT1PR,  RCT1PE,  RCT1TE
           RCT1NMB,RCT1NEQ,RCT1NCO, RCT1NVO, RCT1NP1, RCT1NT1, COSRCT1, RCT1CQ
           RCT1BM1, RCT1BM2, RCT1BM3, RCT1BM4, RCT1BM5(COM), RCT1BM6
           RCT1NO1(COM), RCT1NO2(COM), RCT1TNO1, RCT1TNO2, RCT1PNO1, RCT1PNO2 ;

RCT1MB ..  CONSUM('1') =E= CONV('1') * FC('14','H2')      ;
RCT1HB ..  (F('14')*T('14') - F('16')*T('16')) * CP =E=
           HEATRXN * CONSUM('1') / 100 ;
RCT1CMA..  FC('16','H2')    =E= FC('14','H2')   - 1.*CONSUM('1') ;
RCT1CMB..  FC('16','CO')    =E= FC('14','CO')   - .5*CONSUM('1') ;
RCT1CMC..  FC('16','CH3OH') =E= FC('14','CH3OH')+ .5*CONSUM('1') ;
RCT1CMD..  FC('16','CH4')   =E= FC('14','CH4')                   ;
RCT1EQ ..  CONVEQ('1') =E= 0.415*(1-(26.25*EXP(-1800/(100*
           RCTT('1')+ep)) / SQR(RCTP('1')+ ep))) ;
RCT1CO ..  F('14')* CONV('1') =E= CONVEQ('1') * (1 - EXP(-VPAR('1')* RCTVOL('1')))
           *(FC('14','H2')+FC('14','CO')+FC('14','CH3OH')) ;
RCT1VO ..  RCTVOL('1') =E= 100   ;
RCT1PR ..  RCTP('1')   =E= P('14')        ;
RCT1PE ..  P('16')     =E= 0.9 * RCTP('1');
RCT1TE ..  RCTT('1')   =E= T('16')        ;
RCT1NMB..  CONSUM('1')  =E= 0.0   ;
RCT1NEQ..  CONVEQ('1')  =E= 0.0   ;
RCT1NCO..  CONV('1')    =E= 0.0   ;
RCT1NVO..  RCTVOL('1')  =E= 0.0   ;
RCT1NP1..  RCTP('1')    =E= 0.0   ;
RCT1NT1..  RCTT('1')    =E= 0.0   ;
COSRCT1..  CEQ('9')    =E= 100.   ;
RCT1CQ ..  CONVEQ('1') =G= CONV('1')                      ;
RCT1BM1..  CONV('1')   =L= 0.415                          ;
RCT1BM2..  CONVEQ('1') =L= 0.415                          ;
RCT1BM3..  RCTVOL('1') =L= 100.0                          ;
RCT1BM4..  CONSUM('1') =L=  5.00                          ;
RCT1BM5(COM).. FC('14',COM)=L= 10.00                      ;
RCT1BM6     .. P('16')     =L= 15.00                      ;
RCT1NO1(COM) ..  FC('14',COM)=E= 0.                       ;
RCT1NO2(COM) ..  FC('16',COM)=E= 0.                       ;
RCT1TNO1 ..  T('14')    =E= 0.                         ;
RCT1TNO2 ..  T('16')    =E= 0.                         ;
RCT1PNO1 ..  P('14')    =E= 0.                         ;
RCT1PNO2 ..  P('16')    =E= 0.                         ;
* --------------
* - REACTOR #2 -
* --------------
 EQUATIONS  RCT2MB, RCT2HB, RCT2CMA, RCT2CMB, RCT2CMC, RCT2CMD
    RCT2EQ, RCT2CO, RCT2VO,  RCT2PR,  RCT2PE,  RCT2TE
    RCT2NMB,RCT2NEQ,RCT2NCO, RCT2NVO, RCT2NP1, RCT2NT1, COSRCT2
    RCT2CQ, RCT2BM1, RCT2BM2, RCT2BM3, RCT2BM4, RCT2BM5(COM), RCT2BM6,
    RCT2NO1(COM), RCT2NO2(COM), RCT2TNO1, RCT2TNO2, RCT2PNO1, RCT2PNO2    ;

RCT2MB ..  CONSUM('2') =E= CONV('2') * FC('15','H2')             ;
RCT2HB ..  F('15')*CP*T('15') - F('17')*CP * T('17') =E=
           HEATRXN * CONSUM('2') / 100                           ;
RCT2CMA..  FC('17','H2')    =E= FC('15','H2')    - 1.*CONSUM('2');
RCT2CMB..  FC('17','CO')    =E= FC('15','CO')    - .5*CONSUM('2');
RCT2CMC..  FC('17','CH3OH') =E= FC('15','CH3OH') + .5*CONSUM('2');
RCT2CMD..  FC('17','CH4')   =E= FC('15','CH4')                   ;
RCT2EQ ..  CONVEQ('2') =E= 0.415*(1-(26.25*EXP(-1800/(100*
           RCTT('2')+ep)) / SQR(RCTP('2')+ep)))                        ;
RCT2CO ..  F('15')*CONV('2') =E= CONVEQ('2')*(1 - EXP(-VPAR('2')* RCTVOL('2')))
           *(FC('15','H2')+FC('15','CO')+FC('15','CH3OH')) ;
RCT2VO..   RCTVOL('2') =E= 100                   ;
RCT2PR..   RCTP('2')   =E= P('15')               ;
RCT2PE..   P('17')     =E= 0.9 * RCTP('2')       ;
RCT2TE..   RCTT('2')   =E= T('17')               ;
RCT2NMB..  CONSUM('2')  =E= 0.0                  ;
RCT2NEQ..  CONVEQ('2')  =E= 0.0                  ;
RCT2NCO..  CONV('2')    =E= 0.0                  ;
RCT2NVO..  RCTVOL('2')  =E= 0.0                  ;
RCT2NP1..  RCTP('2')    =E= 0.0                  ;
RCT2NT1..  RCTT('2')    =E= 0.0                  ;
COSRCT2..  CEQ('10')    =E= 250.                 ;
RCT2CQ..   CONVEQ('2') =G= CONV('2')             ;
RCT2BM1..  CONV('2')   =L= 0.415                 ;
RCT2BM2..  CONVEQ('2') =L= 0.415                 ;
RCT2BM3..  RCTVOL('2') =L= 100.0                 ;
RCT2BM4..  CONSUM('2') =L=  5.00                 ;
RCT2BM5(COM)..     FC('15',COM)=L= 10.00         ;
RCT2BM6..          P('17')     =L= 15.00         ;
RCT2NO1(COM) ..    FC('15',COM)=E= 0.            ;
RCT2NO2(COM) ..    FC('17',COM)=E= 0.            ;
RCT2TNO1 ..         T('15')    =E= 0.            ;
RCT2TNO2 ..         T('17')    =E= 0.            ;
RCT2PNO1 ..         P('15')    =E= 0.            ;
RCT2PNO2 ..         P('17')    =E= 0.            ;
* -----------
* - FEED #2 -
* -----------
 EQUATIONS
    FEE2CA, FEE2CB, FEE2CD, FEE2TEMP, FEE2PRES, FEE2N(COM), FEE2BM1(COM),
    FEE2TNO, FEE2PNO; ;
FEE2CA     ..  FC('2','H2')    =E= 0.65 * F('2')  ;
FEE2CB     ..  FC('2','CO')    =E= 0.30 * F('2')  ;
FEE2CD     ..  FC('2','CH4')   =E= 0.05 * F('2')  ;
FEE2BM1(COM) .. FC('2',COM) =L= 5.0               ;
FEE2TEMP   ..  T('2')          =E= 3.0            ;
FEE2PRES   ..  P('2')          =E= 1.0            ;
FEE2N(COM) ..  FC('2',COM)     =E= 0.0            ;
FEE2TNO..      T('2')          =E= 0.0            ;
FEE2PNO..      P('2')          =E= 0.0            ;

* -------------------
* - EXPANSION VALVE -
* -------------------
 EQUATIONS   VALCMB(COM), VALT, VALP                    ;
VALCMB(COM) .. FC('19',COM) =E= FC('18',COM)   ;
VALT        .. T('19')/(P('19') ** GAM) =E= T('18')/(P('18') ** GAM);
VALP        .. P('19')      =L= P('18')        ;

* -------------------
* - FLASH SEPARATOR -
* -------------------
 EQUATIONS FLSCMB(COM), FLSANT(COM), FLSRECB,FLSRECC,FLSRECD, FLSEQU(COM)
           FLSPRE, FLSPR1, FLSPR2, FLSPR3, FLSTE1, FLSTE2, FLSTE3        ;

FLSCMB(COM)..  FC('20',COM) =E= FC('21',COM) + FC('22',COM);
FLSANT(COM)..  LOG(VP(COM) * 7500.6168) =E= ANTA(COM) -
                ANTB(COM) / (FLSHT * 100 - ANTC(COM))   ;
FLSRECB    ..  EFLSH('H2') * (EFLSH('CO') * VP('H2') +
                (1 - EFLSH('CO')) * VP('CO')) =E= VP('H2') * EFLSH('CO') ;
FLSRECC    ..  EFLSH('H2')*(EFLSH('CH3OH')*VP('H2') +
               (1-EFLSH('CH3OH')) * VP('CH3OH')) =E= VP('H2') * EFLSH('CH3OH');
FLSRECD    ..  EFLSH('H2')*(EFLSH('CH4')*VP('H2')  +
               (1 - EFLSH('CH4')) * VP('CH4')) =E= VP('H2') * EFLSH('CH4');
FLSEQU(COM)..  FC('21',COM) =E= EFLSH(COM) * FC('20',COM);
FLSPRE     ..  FLSHP =E= SUM(COM, VP(COM) * FC('22',COM)) / F('22');
FLSPR1     ..  FLSHP =E= P('20')  ;
FLSPR2     ..  FLSHP =E= P('21')  ;
FLSPR3     ..  FLSHP =E= P('22')  ;
FLSTE1     ..  FLSHT =E= T('20')  ;
FLSTE2     ..  FLSHT =E= T('21')  ;
FLSTE3     ..  FLSHT =E= T('22')  ;


* ----------------------
* - OBJECTIVE FUNCTION -
* ----------------------
 EQUATIONS    OBJ              COST FUNCTION DEFINITION   ;

OBJ .. PROF =E=(-795.6*F('1')-1009.8*F('2')+7650*F('23')+642.6*F('25')
                 - 5 * RCTVOL('1') - 10 * RCTVOL('2')
                 - SUM(COMP , ELEC(COMP) * 0.175 * 1000.)
                 - SUM(COMP , COSTELEC * ELEC(COMP) )
                 - SUM(HEC  , COSTQC * QC(HEC) )
                 - SUM(HEH  , COSTQH * QH(HEH) )
                 - SUM(I, CEQ(I))) ;


* ---------------------
* - LOGIC CONSTRAINTS -
* ---------------------
 EQUATIONS
    L1,  L2,  L3,  L4,  L5,  L6,  L7,  L8,  L9,  L10
    L11, L12, L13, L14, L15, L16, L17, L18, L19, L20
    L21, L22, L23, L24, L25
    L81, L82, L83                    ;
*
L1    ..  Y('1')  + Y('2')             =E= 1   ;
L2    .. -Y('1')  + Y('3')  + Y('4')   =G= 0   ;
L3    .. -Y('2')  + Y('3')  + Y('4')   =G= 0   ;
L4    ..  Y('3')  + Y('4')             =L= 1   ;
L5    ..  Y('3')  + Y('5')             =L= 1   ;
L6    ..  Y('3')  + Y('6')             =L= 1   ;
L7    .. -Y('4')  + Y('5')             =E= 0   ;
L8    .. -Y('5')  + Y('6')             =E= 0   ;
L81   .. -Y('3')  + Y('7')             =G= 0    ;
L82   .. -Y('6')  + Y('7')             =G= 0    ;
L83   ..  -Y('7') + Y('8')             =G= 0   ;
L9    ..  Y('7')  + Y('8')             =L= 2   ;
L10   .. -Y('7')  + Y('9')  + Y('10')  =G= 0   ;
L11   .. -Y('8')  + Y('9')  + Y('10')  =G= 0   ;
L12   .. -Y('3')  + Y('9')  + Y('10')  =G= 0   ;
L13   .. -Y('4')  + Y('9')  + Y('10')  =G= 0   ;
L14   ..  Y('9')  + Y('10')            =E= 1   ;
L15   .. -Y('9')  + Y('11')            =G= 0   ;
L16   .. -Y('10') + Y('11')            =G= 0   ;
L17   .. -Y('11') + Y('9')  + Y('10')  =G= 0   ;
L18   .. -Y('11') + Y('12')            =E= 0   ;
L19   .. -Y('12') + Y('13')            =G= 0   ;
L20   ..  Y('13')                      =E= 1   ;
L21   ..  Y('16') + Y('17')            =L= 1   ;
L22   ..  Y('16') + Y('18')            =L= 1   ;
L23   ..  Y('16') + Y('19')            =L= 1   ;
L24   .. -Y('17') + Y('18')            =E= 0   ;
L25   .. -Y('18') + Y('19')            =E= 0   ;


 OPTION  MINLP    = LMLBOA ;
 OPTION  LIMROW   = 0        ;
 OPTION  LIMCOL   = 0        ;
 OPTION  SOLPRINT = ON       ;
 OPTION  SYSOUT   = OFF      ;
 OPTION  OPTCR    = 0.0      ;
 OPTION  RESLIM   = 1000000  ;
 OPTION  ITERLIM  = 1000000  ;
* OPTION NLP = conopt2;


***************************************************************
* INITIALIZATIONS SECTION VERY IMPORTANT TO REACH THE SOLUTION
***************************************************************
Y.L('1')=1;
*Y.L('2')=1.;
*Y.L('3')=1.;
Y.L('4')=1;
Y.L('5')=1;
Y.L('6')=1;
Y.L('7')=1;
Y.L('8')=1;
*Y.L('9')=1;
Y.L('10')=1;
Y.L('11')=1;
Y.L('12')=1;
Y.L('13')=1;
Y.L('14')=1;
Y.L('15')=1;
*Y.L('16')=1;
Y.L('17')=1;
Y.L('18')=1;
Y.L('19')=1;
Y.UP(I)=1.;

* -----------------------
* BOUNDS & INITIAL POINTS
* -----------------------

* STREAM :
 F.LO(STR)      = 0.0  ;
 F.UP(STR)      = 20.0 ;
 FC.LO(STR,COM) = 0.0  ;
 FC.UP(STR,COM) = 20.0 ;
 P.LO(STR)      = 0.0  ;
 P.UP(STR)      = 15.0 ;
 T.LO(STR)      = 0.0  ;
 T.UP(STR)      = 9.0  ;
 F.L(STR) = 4.;
 P.L(STR) = 5.;
 T.L(STR) = 3.;

* -----
* FEED1
* -----
 F.UP('1')               = 5.0   ;
 F.LO('1')               = 0.    ;
 T.L('1')                = 3.0   ;
 P.L('1')                = 1.0   ;
 FC.FX('1','CH3OH')      = 0.0   ;
 F.L('1')          = 4.5        ;
 FC.L('1','H2')    = 0.60 * F.L('1')  ;
 FC.L('1','CO')    = 0.25 * F.L('1')  ;
 FC.L('1','CH3OH') = 0.00             ;
 FC.L('1','CH4')   = 0.15 * F.L('1')  ;
 T.L('1')          = 3.0              ;
 P.L('1')          = 1.0              ;

* -----
* FEED2
* -----
 F.UP('2')               = 5.0  ;
 F.LO('2')               = 0.   ;
 T.L('2')                = 3.0  ;
 P.L('2')                = 1.0  ;
 F.L('2')                = 3.5  ;
 FC.L('2','H2')    = 0.65 * F.L('2')  ;
 FC.L('2','CO')    = 0.30 * F.L('2')  ;
 FC.L('2','CH3OH') = 0.00             ;
 FC.L('2','CH4')   = 0.05 * F.L('2')  ;
 T.L('2')          = 3.0             ;
 P.L('2')          = 1.0              ;

* --------------
* MIXING POINT 1
* --------------
 FC.FX('3','CH3OH')      = 0.0  ;
 F.L('3')      = F.L('1') *Y.L('1')      + F.L('2') *Y.L('2')     ;
 FC.L('3',COM) = FC.L('1',COM)*Y.L('1') + FC.L('2',COM)*Y.L('2') ;
 T.L('3')      = T.L('1') *Y.L('1')     + T.L('2')  *Y.L('2')    ;
 P.L('3')      = P.L('1') *Y.L('1')     + P.L('2')  *Y.L('2')    ;

* -------------
* SPLIT POINT 1
* -------------
 F.L('4')      = F.L('3')       ;
 FC.L('4',COM) = FC.L('3',COM)  ;
 F.L('5')      = F.L('3')       ;
 FC.L('5',COM) = FC.L('3',COM)  ;
 T.L('4')      = T.L('3')       ;
 P.L('4')      = P.L('3')       ;
 T.L('5')      = T.L('3')       ;
 P.L('5')      = P.L('3')       ;

* ----------------------------
* SINGLE STAGE FEED COMPRESSOR
* ----------------------------
 PRAT.LO(COMP)  = 0.0   ;
 PRAT.UP(COMP)  = 1.74  ;
 ELEC.LO(COMP)  = 0.0   ;
 ELEC.UP(COMP)  = 50.0  ;
 F.L('6')      = F.L('4')                 ;
 FC.L('6',COM) = FC.L('4',COM)             ;
 P.L('6')      = 10.0                     ;
 PRAT.L('1') = (P.L('6')/(P.L('4')+0.01)) ** GAM  ;
 ELEC.L('1')   = (ALPHA * (PRAT.L('1') - 1)
                 *F.L('4') / (10 * GAM * CEFF))          ;
 T.L('6')      = PRAT.L('1') * T.L('4')               ;

* --------------------------------------------
* FIRST STAGE OF THE TWO STAGE FEED COMPRESSOR
* --------------------------------------------
 F.L('7')      = F.L('5')           ;
 FC.L('7',COM) = FC.L('5',COM)      ;
 P.L('7')      = 8                  ;
 PRAT.L('2') = (P.L('7')/(P.L('5')+0.01)) ** GAM ;
 ELEC.L('2')   = ALPHA * (PRAT.L('2') - 1) * T.L('5') *
                  F.L('5') / (10 * GAM * CEFF)         ;
 T.L('7')      = PRAT.L('2') * T.L('5')                ;

* --------------------------------------------
* INTERCOOLER OF THE TWO STAGE FEED COMPRESSOR
* --------------------------------------------
 QC.LO(HEC)   = 0.0 ;
 QC.UP(HEC)   = 50.0;
 F.L('8')      = F.L('7')               ;
 FC.L('8',COM) = FC.L('7',COM)          ;
 P.L('8')      = P.L('7')               ;
 T.L('8')      = T.L('7')               ;
 QC.L('1')     = (F.L('7')*T.L('7') -
     F.L('8')*T.L('8')) * CP * (3600*8500*100*1.0E-12)   ;


* ---------------------------------------------
* SECOND STAGE OF THE TWO STAGE FEED COMPRESSOR
* ---------------------------------------------
 F.L('9')      = F.L('8')         ;
 FC.L('9',COM) = FC.L('8',COM)    ;
 P.L('9')      = 10.0             ;
 PRAT.L('3') = (P.L('9')/(P.L('8')+0.01)) ** GAM  ;
 ELEC.L('3')   = ALPHA * (PRAT.L('3') - 1) * T.L('8') *
                  F.L('8') / (10 * GAM * CEFF)        ;
 T.L('9')      = PRAT.L('3') * T.L('8')               ;

* --------------
* MIXING POINT 2
* --------------
 F.L('10')     = F.L('6') *Y.L('3')     + F.L('9') *Y.L('6')     ;
 FC.L('10',COM)= FC.L('6',COM)*Y.L('3') + FC.L('9',COM)*Y.L('6') ;
 T.L('10')     = T.L('6') *Y.L('3')     + T.L('9')*Y.L('6')      ;
 P.L('10')     = P.L('6') *Y.L('3')     + P.L('9')*Y.L('6')      ;

* --------------
* MIXING POINT 3
* --------------
 FC.L('33','H2')    = 4.5       ;
 FC.L('33','CO')    = 0.1       ;
 FC.L('33','CH3OH') = 4.1       ;
 FC.L('33','CH4')   = 4.1       ;
 P.L('33')          = P.L('10') ;
 F.L('11')      = F.L('10')      + F.L('33')      ;
 FC.L('11',COM) = FC.L('10',COM) + FC.L('33',COM) ;
 T.L('11')      =  (F.L('10') * T.L('10') +
          F.L('33') * T.L('33')) /( F.L('11')+0.01)      ;
 P.L('11')      = P.L('10')                       ;

* -------------------
* REACTOR FEED COOLER
* -------------------
 F.L('12')      = F.L('11')      ;
 FC.L('12',COM) = FC.L('11',COM) ;
 P.L('12')      = P.L('11')      ;
 T.L('12')      = 4.5            ;
 QC.L('2')$(T.L('11') GT 450)  = (F.L('11')*T.L('11') -
       F.L('12')*T.L('12')) * CP * (3600*8500*100*1.0E-12)   ;
 QC.L('2')$(T.L('11') LE 450)  = 0.0                         ;

* -------------------
* REACTOR FEED HEATER
* -------------------
 QH.LO(HEH)   = 0.0 ;
 QH.UP(HEH)   = 50.0;

 F.L('13')      = F.L('12')      ;
 FC.L('13',COM) = FC.L('12',COM) ;
 P.L('13')      = P.L('12')      ;
 T.L('13')      = 4.5            ;
 QH.L('1')$(T.L('12') LT 450) = (F.L('13')*T.L('13') -
       F.L('12')*T.L('12')) * CP * (3600*8500*100*1.0E-12)    ;
 QH.L('1')$(T.L('12') GE 450) = 0.0                           ;

* -------------
* SPLIT POINT 2
* -------------
 F.L('14')      = F.L('13')      ;
 FC.L('14',COM) = FC.L('13',COM) ;
 F.L('15')      = F.L('13')      ;
 FC.L('15',COM) = FC.L('13',COM) ;
 P.L('14')      = P.L('13')      ;
 T.L('14')      = T.L('13')      ;
 P.L('15')      = P.L('13')      ;
 T.L('15')      = T.L('13')      ;
* ---------
* REACTOR 1
* ---------
 CONSUM.LO(RCT) = 0.0   ;
 CONSUM.UP(RCT) = 5.0   ;
 CONV.LO(RCT)   = 0.000 ;
 CONV.UP(RCT)   = 0.420 ;
 CONVEQ.UP(RCT) = 0.420 ;
 RCTP.LO(RCT)   = 0.0   ;
 P.LO('13')     = 0.    ;
 P.LO('14')     = 0.    ;
 RCTP.UP(RCT)   = 15.0  ;
 RCTT.LO(RCT)   = 0.0   ;
 T.LO('14') = 0.00000001  ;
 T.LO('16') = 0.00000001  ;
 FC.LO('16',COM)= 0.00000001 ;
 RCTT.UP(RCT)   = 8.73  ;
 T.UP('16')     = 8.73  ;
 T.LO('13')     = 0.  ;
 T.UP('13')     = 8.73  ;
 T.LO('18')     = 0.  ;
 T.UP('18')     = 8.73  ;
 RCTVOL.LO(RCT) = 0.0   ;
 RCTVOL.UP(RCT) = 100.0 ;
 RCTP.L('1')   = P.L('14')   ;
 RCTT.L('1')   = 5.25        ;
 RCTVOL.L('1') = 100.0       ;
 CONVEQ.L('1') = 0.4         ;
 CONV.L('1')   = (CONVEQ.L('1')*(1.-EXP(-VPAR('1') *
                       RCTVOL.L('1')))*(FC.L('14','H2') +
                       FC.L('14','CO')+FC.L('14','CH3OH'))/(F.L('14')+0.01));
 CONV.L('1')= 0.0                                     ;
 CONSUM.L('1')     = CONV.L('1') * FC.L('14','H2')                   ;
 FC.L('16','H2')   = (FC.L('14','H2')    - 2 * CONSUM.L('1'))  ;
 FC.L('16','CO')   = (FC.L('14','CO')    - 1 * CONSUM.L('1'))  ;
 FC.L('16','CH3OH')= (FC.L('14','CH3OH') + 1 * CONSUM.L('1'))  ;
 FC.L('16','CH4')  = FC.L('14','CH4')  * Y.L('9')              ;
 F.L('16')         = SUM( COM , FC.L('16',COM))                ;
 P.L('16')         = 0.9 * P.L('14')                           ;
 T.L('16')         = RCTT.L('1')                               ;

* ---------
* REACTOR 2
* ---------
 P.LO('15') = 0.      ;
 T.LO('15') = 0.     ;
 T.LO('17') = 0.     ;
 FC.LO('17',COM) = 0.0 ;
 T.UP('17')     = 8.73  ;

 RCTP.L('2')   = P.L('15')   ;
 RCTT.L('2')   = 5.25        ;
 RCTVOL.L('2') =  100.0      ;
 CONVEQ.L('2') = 0.4         ;
 CONV.L('2')= (CONVEQ.L('2')*(1.-EXP(-VPAR('2') *
                       RCTVOL.L('2')))*(FC.L('15','H2') +
                       FC.L('15','CO')+FC.L('15','CH3OH'))/(F.L('15')+0.01)) ;
 CONSUM.L('2')     = CONV.L('2') * FC.L('15','H2')                   ;
 FC.L('17','H2')   = (FC.L('15','H2')    - 1   * CONSUM.L('2'))      ;
 FC.L('17','CO')   = (FC.L('15','CO')    - 1/2 * CONSUM.L('2'))      ;
 FC.L('17','CH3OH')= (FC.L('15','CH3OH') + 1/2 * CONSUM.L('2'))      ;
 FC.L('17','CH4')  = FC.L('15','CH4')                                ;
 F.L('17')         = SUM( COM , FC.L('17',COM))                      ;
 P.L('17')         = 0.9 * P.L('15')                                 ;
 T.L('17')         = RCTT.L('2')                                     ;

* --------------
* MIXING POINT 4
* --------------
 F.L('18')      = F.L('16') *Y.L('9')     + F.L('17')*Y.L('10')      ;
 FC.L('18',COM) = FC.L('16',COM)*Y.L('9') + FC.L('17',COM)*Y.L('10') ;
 T.L('18')      = T.L('16')*Y.L('9')      + T.L('17')*Y.L('10')      ;
 P.L('18')      = P.L('16')*Y.L('9')      + P.L('17')*Y.L('10')      ;

* ---------------
* EXPANSION VALVE
* ---------------
 P.L('19')      = 9.5                                      ;
 F.L('19')      = F.L('18')                                ;
 FC.L('19',COM) = FC.L('18',COM)                           ;
 T.L('19')      = T.L('18') * (P.L('18')/P.L('19')) ** GAM ;

* ----------------------
* FLASH SEPARATOR COOLER
* ----------------------
 T.L('20')      = 4.0            ;
 F.L('20')      = F.L('19')      ;
 FC.L('20',COM) = FC.L('19',COM) ;
 P.L('20')      = P.L('19')      ;
 QC.L('3')      = (F.L('19')*T.L('19') -
      F.L('20')*T.L('20')) * CP * (3600*8500*100*1.0E-12)    ;

* ---------------
* FLASH SEPARATOR
* ---------------
 F.LO('22')       = 0.1   ;
 F.UP('22')       = 1.0   ;
 EFLSH.LO(COM)    = 0.01  ;
 EFLSH.UP(COM)    = 0.9999;
 FLSHP.LO         = 0.25  ;
 FLSHP.UP         = 15.0  ;
 FLSHT.LO         = 3.4   ;
 FLSHT.UP         = 5.0   ;
 VP.LO(COM)       = (1./7500.6168) * EXP(ANTA(COM) -
         ANTB(COM) / (FLSHT.LO * 100. + ANTC(COM)))  ;
 VP.UP(COM)       = (1./7500.6168) * EXP(ANTA(COM) -
         ANTB(COM) / (FLSHT.UP * 100. + ANTC(COM)))  ;

 FLSHP.L      = P.L('20')                                                ;
 FLSHT.L      = 3.9;                                              ;
 VP.L(COM)    = (1./7500.6168)*EXP(ANTA(COM) -
                ANTB(COM)/(FLSHT.L*100.+ANTC(COM)))                      ;
 EFLSH.L('H2')= 0.995                                                    ;
 EFLSH.L(COM) = (VP.L(COM)*EFLSH.L('H2')/VP.L('H2')) / (1.0+EFLSH.L('H2')
                * (VP.L(COM) - VP.L('H2')) / VP.L('H2'))                 ;
 FC.L('21',COM) = FC.L('20',COM) * EFLSH.L(COM)     ;
 FC.L('22',COM) = FC.L('20',COM) - FC.L('21',COM)   ;
 F.L('22')      = SUM(COM, FC.L('21',COM))          ;
 F.L('21')      = SUM(COM, FC.L('22',COM))          ;
 P.L('21')      = FLSHP.L                           ;
 P.L('22')      = FLSHP.L                           ;
 T.L('21')      = FLSHT.L                           ;
 T.L('22')      = FLSHT.L                           ;

* --------------
* PRODUCT HEATER
* --------------
 F.LO('23')     = 0.1   ;
 F.UP('23')     = 1.0   ;
 F.L('23')      = F.L('22')      ;
 FC.L('23',COM) = FC.L('22',COM) ;
 P.L('23')      = P.L('22')      ;
 T.FX('23')     = 4.0            ;
 QH.L('2')      = (F.L('23')*T.L('23') -
   F.L('22')*T.L('22')) * CP * (3600*8500*100*1.0E-12)    ;

* -------------
* SPLIT POINT 3
* -------------
 E26.LO  = 0.01  ;
 E26.UP  = 0.99  ;
 E26.L  = 0.9      ;
 FC.L('26',COM)     = FC.L('21',COM) * E26.L          ;
 F.L('26')          = SUM(COM, FC.L('26',COM))        ;
 F.L('24')          = F.L('21')      - F.L('26')      ;
 FC.L('24',COM)     = FC.L('21',COM) - FC.L('26',COM) ;
 T.L('24')          = T.L('21')                       ;
 T.L('26')          = T.L('21')                       ;
 P.L('24')          = P.L('21')                       ;
 P.L('26')          = P.L('21')                       ;

* -----------------
* BY-PRODUCT HEATER
* -----------------
 F.L('25')      = F.L('24')      ;
 FC.L('25',COM) = FC.L('24',COM) ;
 T.FX('25')     = 4.0            ;
 P.L('25')      = P.L('24')      ;

* -------------
* SPLIT POINT 4
* -------------
 F.L('27')      = F.L('26')       ;
 FC.L('27',COM) = FC.L('26',COM)  ;
 F.L('28')      = F.L('26')       ;
 FC.L('28',COM) = FC.L('26',COM)  ;
 T.L('27')      = T.L('26')       ;
 T.L('28')      = T.L('26')       ;
 P.L('27')      = P.L('26')       ;
 P.L('28')      = P.L('26')       ;

* -------------------------------
* SINGLE STAGE RECYCLE COMPRESSOR
* -------------------------------
 F.L('29')      = F.L('27')                       ;
 FC.L('29',COM) = FC.L('27',COM)                  ;
 P.L('29')      = 12                              ;
 PRAT.L('4')    = (P.L('29')/(P.L('27')+0.01)) ** GAM ;
 ELEC.L('4')    = (ALPHA * (PRAT.L('4') - 1) * T.L('27') *
                   F.L('27') / (10 * GAM * CEFF))          ;
 T.L('29')      = PRAT.L('4') * T.L('27')                  ;

* -----------------------------------------------
* FIRST STAGE OF THE TWO STAGE RECYCLE COMPRESSOR
* -----------------------------------------------
 F.L('30')      = F.L('28')                         ;
 FC.L('30',COM) = FC.L('28',COM)                    ;
 P.L('30')      = 9                                 ;
 PRAT.L('5') = (P.L('30')/(P.L('28')+0.01)) ** GAM  ;
 ELEC.L('5')    = (ALPHA * (PRAT.L('5') - 1) * T.L('28') *
                   F.L('28') / (10 * GAM * CEFF))   ;
 T.L('30')      = PRAT.L('5') * T.L('28')           ;

* -----------------------------------------------
* INTERCOOLER OF THE TWO STAGE RECYCLE COMPRESSOR
* -----------------------------------------------
* P.FX('30')$(YMT('18') EQ 0) = 0.0 ;

 F.L('31')      = F.L('30')    ;
 FC.L('31',COM) = FC.L('30',COM) ;
 P.L('31')      = P.L('30')      ;
 T.L('31')      = T.L('30')       ;
 QC.L('4') = ((F.L('30')*T.L('30') -
        F.L('31')*T.L('31')) * CP * (3600*8500*100*1.0E-12))  ;
 QC.L('4') = 0.0                             ;

* ------------------------------------------------
* SECOND STAGE OF THE TWO STAGE RECYCLE COMPRESSOR
* ------------------------------------------------
 F.L('32')      = F.L('31')                               ;
 FC.L('32',COM) = FC.L('31',COM)                          ;
 P.L('32')      = P.L('9')                                ;
 PRAT.L('6')    = (P.L('32')/(P.L('31')+0.01)) ** GAM     ;
 ELEC.L('6')    = (ALPHA * (PRAT.L('6') - 1) * T.L('31') *
                   F.L('31') / (10 * GAM * CEFF))          ;
 T.L('32')      = PRAT.L('6') * T.L('31')                 ;

* --------------
* MIXING POINT 5
* --------------
 F.L('33')      = F.L('29') *Y.L('16')     + F.L('32')*Y.L('19')      ;
 FC.L('33',COM) = FC.L('29',COM)*Y.L('16') + FC.L('32',COM)*Y.L('19') ;
 T.L('33')      = T.L('29') *Y.L('16')     + T.L('32')  *Y.L('19')    ;
 P.L('33')      = P.L('29') *Y.L('16')      + P.L('32') *Y.L('19')     ;
*********************************
* END OF INITIALIZATIONS SECTION
*********************************

*********************************
* STARTS LogMIP SECTION
*********************************
$ONECHO > "%lm.info%"
DISJUNCTION D1, D2, D3, D4, D5, D6, D9, D10, D16, D17, D18, D19;

D1 is
IF Y('1') Then
         FEE1CA      ;
         FEE1CB      ;
         FEE1CD      ;
         fee1bm1('CH3OH');
*         FEE1BM1(COM) with ord(com) >= 1;
         FEE1TEMP    ;
         FEE1PRES    ;
else
         FEE1N(COM) with ord(com) >= 1 ;
         FEE1TNO;
         FEE1PNO;
endif ;

D2 is
IF Y('2') Then
         FEE2CA      ;
         FEE2CB      ;
         FEE2CD      ;
         FEE2BM1(COM) with ord(com) >= 1;
         FEE2TEMP    ;
         FEE2PRES    ;
else
         FEE2N(COM) with ord(com) >= 1 ;
         FEE2TNO;
         FEE2PNO;
endif  ;

D3 is
If Y('3') then
         COM1CMB(COM) with ord(com) >= 1;
         COM1TEMP ;
         COM1ELEC ;
         COM1RATIO;
         COM1BM1  ;
         COM1BM2(COM) with ord(com) >= 1;
         COM1BM3  ;
         COM1BM4  ;
         COM1BM5  ;
         COM1BM6  ;
         COM1BM7  ;
         COM1BM8  ;
         COM1BM9  ;
else
         COM1NO1(COM) with ord(com) >= 1;
         COM1NO2(COM) with ord(com) >= 1;
         COM1TNO1; COM1TNO2; COM1PNO1; COM1PNO2; PRATNO1; ELECNO1;
endif   ;

D4 is
If Y('4') then
         COM2CMB(COM) with ord(com) >= 1;
         COM2TEMP  ;
         COM2ELEC  ;
         COM2RATIO ;
         COM2BM1   ;
         COM2BM2(COM) with ord(com) >= 1;
         COM2BM3   ;
         COM2BM4   ;
         COM2BM5   ;
         COM2BM6   ;
         COM2BM7   ;
         COM2BM8   ;
         COM2BM9   ;
         COSCOM4   ;
else
         COM2NO1(COM) with ord(com) >= 1;
         COM2NO2(COM) with ord(com) >= 1;
         COM2TNO1; COM2TNO2; COM2PNO1; COM2PNO2; PRATNO2; ELECNO2;
endif    ;

D5 is
if Y('5') then
         COO1CMB(COM) with ord(com) >= 1;
         COO1DUTY     ;
         COO1PRES     ;
         COO1BM1      ;
         COO1BM2(COM) with ord(com) >= 1;
         COO1BM3      ;
         COO1BM4      ;
         COO1BM5      ;
else
         COO1NO1(COM) with ord(com) >= 1;
         COO1NO2(COM) with ord(com) >= 1;
         COO1TNO1; COO1TNO2; COO1PNO1; COO1PNO2; QNO1;
endif     ;

D6 is
If Y('6') then
         COM3CMB(COM) with ord(com) >= 1;
         COM3TEMP   ;
         COM3ELEC   ;
         COM3RATIO  ;
         COM3R      ;
         COM3BM1    ;
         COM3BM2(COM) with ord(com) >= 1;
         COM3BM3    ;
         COM3BM4    ;
         COM3BM5    ;
         COM3BM6    ;
         COM3BM7    ;
         COM3BM8    ;
         COM3BM9    ;
         COSCOM6    ;
else
         COM3NO1(COM) with ord(com) >= 1;
         COM3NO2(COM) with ord(com) >= 1;
         COM3TNO1; COM3TNO2; COM3PNO1; COM3PNO2; PRATNO3; ELECNO3;
endif      ;


D9 is
if Y('9') then
         RCT1MB  ;
         RCT1HB  ;
         RCT1CMA ;
         RCT1CMB ;
         RCT1CMC ;
         RCT1CMD ;
         RCT1EQ  ;
         RCT1CO  ;
         RCT1VO  ;
         RCT1PR  ;
         RCT1PE  ;
         RCT1TE  ;
         COSRCT1 ;
         RCT1CQ  ;
         RCT1BM1 ;
         RCT1BM2 ;
         RCT1BM3 ;
         RCT1BM4 ;
         RCT1BM5(COM)with ord(com) >= 1 ;
         RCT1BM6  ;
else
         RCT1NMB ;
         RCT1NEQ ;
         RCT1NCO ;
         RCT1NVO ;
         RCT1NP1 ;
         RCT1NT1 ;
         RCT1NO1(COM)with ord(com) >= 1 ;
         RCT1NO2(COM)with ord(com) >= 1;
         RCT1TNO1; RCT1TNO2; RCT1PNO1; RCT1PNO2;
endif       ;

D10 is
if Y('10') then
         RCT2MB  ;
         RCT2HB  ;
         RCT2CMA ;
         RCT2CMB ;
         RCT2CMC ;
         RCT2CMD ;
         RCT2EQ  ;
         RCT2CO  ;
         RCT2VO  ;
         RCT2PR  ;
         RCT2PE  ;
         RCT2TE  ;
         COSRCT2 ;
         RCT2CQ  ;
         RCT2BM1 ;
         RCT2BM2 ;
         RCT2BM3 ;
         RCT2BM4 ;
         RCT2BM5(COM)with ord(com) >= 1 ;
         RCT2BM6  ;
else
         RCT2NMB ;
         RCT2NEQ ;
         RCT2NCO ;
         RCT2NVO ;
         RCT2NP1 ;
         RCT2NT1 ;
         RCT2NO1(COM) with ord(com) >= 1 ;
         RCT2NO2(COM) with ord(com) >= 1 ;
         RCT2TNO1; RCT2TNO2; RCT2PNO1; RCT2PNO2;
endif ;

D16 is
If Y('16') then
         COM4CMB(COM) with ord(com) >= 1;
         COM4TEMP   ;
         COM4ELEC   ;
         COM4RATIO  ;
         COM4T      ;
         COM4BM1    ;
         COM4BM2(COM) with ord(com) >= 1;
         COM4BM3    ;
         COM4BM4    ;
         COM4BM5    ;
         COM4BM6    ;
         COM4BM7    ;
         COM4BM8    ;
         COM4BM9    ;
else
         COM4NO1(COM) with ord(com) >= 1;
         COM4NO2(COM) with ord(com) >= 1;
         COM4TNO1; COM4TNO2; COM4PNO1; COM4PNO2; PRATNO4; ELECNO4;
endif  ;

D17 is
If Y('17') then
         COM5CMB(COM) with ord(com) >= 1;
         COM5TEMP   ;
         COM5ELEC   ;
         COM5RATIO  ;
         COSCOM17   ;
         COM5BM1    ;
         COM5BM2(COM) with ord(com) >= 1;
         COM5BM3    ;
         COM5BM4    ;
         COM5BM5    ;
         COM5BM6    ;
         COM5BM7    ;
         COM5BM8    ;
         COM5BM9    ;
else
         COM5NO1(COM) with ord(com) >= 1;
         COM5NO2(COM) with ord(com) >= 1;
         COM5TNO1; COM5TNO2; COM5PNO1; COM5PNO2; PRATNO5; ELECNO5;
endif   ;

D18 is
if Y('18') then
         COO4CMB(COM)with ord(com) >= 1 ;
         COO4DUTY     ;
         COO4PRES     ;
         COO4BM1      ;
         COO4BM2(COM)with ord(com) >= 1 ;
         COO4BM3      ;
else
         COO4NO1(COM)with ord(com) >= 1 ;
         COO4NO2(COM)with ord(com) >= 1 ;
         COO4TNO1; COO4TNO2; COO4PNO1; COO4PNO2; QNO2;
endif    ;


D19 is
If Y('19') then
         COM6CMB(COM) with ord(com) >= 1;
         COM6TEMP   ;
         COM6ELEC   ;
         COM6RATIO  ;
         COM6R      ;
         COM6BM1    ;
         COM6BM2(COM) with ord(com) >= 1;
         COM6BM3    ;
         COM6BM4    ;
         COM6BM5    ;
         COM6BM6    ;
         COM6BM7    ;
         COM6BM8    ;
         COM6BM9    ;
else
         COM6NO1(COM) with ord(com) >= 1;
         COM6NO2(COM) with ord(com) >= 1;
         COM6TNO1; COM6TNO2; COM6PNO1; COM6PNO2; PRATNO6; ELECNO6;
endif     ;

 INIT TRUE Y('2'), Y('3'), Y('9'), Y('16') ;
 INIT TRUE Y('1'), Y('4'), Y('5'),  Y('6'),  Y('10'), Y('17'), Y('18'), Y('19');


$offecho
 option minlp=lmlboa;
 MODEL LOGIC / ALL /      ;
 logic.optfile=1;
 logic.workspace=2.;
 SOLVE LOGIC MAXIMIZING PROF USING MINLP ;
